==> omsinterface-1.0.3-sources.jar: com/biz/oms/parseVo/returnGoods/ReturnGoodsVo.java <==
/**
 * @Description: 
 * @ClassName: com.biz.omsadmin.dto.ReturnGoodsDTO
 * @author: dick.dai(Administrator)
 * @date: 2016年5月12日 下午9:38:17 
 */
package com.biz.oms.parseVo.returnGoods;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 申请退货信息
 * @Description: 
 * @ClassName: com.biz.omsadmin.dto.ReturnGoodsDTO
 * @author: dick.dai(Administrator)
 * @date: 2016年5月12日 下午9:38:17 
 *
 */
public class ReturnGoodsVo implements Serializable{

	/**
	 * @Fields serialVersionUID : TODO
	 */
	private static final long serialVersionUID = 1L;
	
	private Integer id;
	/**退货单号*/
	private String returnGoodsBn;
	/**订单编号*/
	private String orderBn;
	/** 退款单号 */
	private String refundBn;
	/** 订单来源*/
	private String orderSource;
	/** 店铺来源*/
	private String shopBn;
	/** 订单状态*/
	private String orderStatus;
	/** 订单总金额*/
	private BigDecimal orderTotalAmount;
	/** 订单商品总金额*/
	private BigDecimal orderCostAmount;
	/** 订单优惠金额*/
	private BigDecimal orderPmtOrder;
	/** 原订单平台优惠*/
	private BigDecimal orderPmtPlateform;
	/** 订单已支付金额*/
	private BigDecimal orderPayed;
	/** 退款总金额*/
	private BigDecimal returnAmount;
	/**退货理由*/
	private String returnReason;
	/** 退货说明*/
	private String returnExplain;
	/** 客户备注*/
	private String customMark;
	/**退货商品信息*/
	private List<ReturnProductInfoVo> returnProductInfos=new ArrayList<ReturnProductInfoVo>();
	/**申请状态:默认为0：申请中*/
	private String applyStatus;
	/**退货人姓名*/
	private String name;
	/**邮编*/
	private String zip;
	/**省*/
	private String areaState;
	/**市/县*/
	private String areaCity;
	/**区*/
	private String areaDistrict;
	/**地址*/
	private String addr;
	/**手机号*/
	private String mobile;
	/**固定电话 */
	private String telephone;
	/** 退回的门店编号*/
	private String storeNo;
	/** 门店地址*/
	private String storeAddress;
	/** 平台来源*/
	private String platformSource;
	/** 操作人*/
	private String operatorName;
	/** 退货单创建时间*/
	private Date createtime;
	/** 退货单申请时间*/
	private Date applyTime;
	/** 物流编号*/
	private String logisticBn;
	/** 物流公司*/
	private String logisticCompany;
	/** 运费*/
	private BigDecimal costShippig;
	/** 是否保价*/
	private boolean isProtect;
	/** 保价费用*/
	private BigDecimal costProtect;
	/** 退货单类型 0:订单退货单  1:换货退货单  2:直返单*/
	private Integer returnGoodsType;
	/** 退货凭证*/
	private String returnGoodsProve;
	/** 退款支付方式*/
	private String payType;
	/** 退款银行*/
	private String accountBank;
	/** 退款银行卡号*/
	private String accountNo;
	/** 退款银行开户行省*/
	private String refundState;
	/** 退款银行开户行市*/	
	private String refundCity;
	/** 是否自动生成退款单*/
	private Boolean isAutoCreateRefund;
	/**
	 * @return the id
	 */
	public Integer getId() {
		return id;
	}
	/**
	 * @param id the id to set
	 */
	public void setId(Integer id) {
		this.id = id;
	}
	/**
	 * @return the returnGoodsBn
	 */
	public String getReturnGoodsBn() {
		return returnGoodsBn;
	}
	/**
	 * @param returnGoodsBn the returnGoodsBn to set
	 */
	public void setReturnGoodsBn(String returnGoodsBn) {
		this.returnGoodsBn = returnGoodsBn;
	}
	/**
	 * @return the orderBn
	 */
	public String getOrderBn() {
		return orderBn;
	}
	/**
	 * @param orderBn the orderBn to set
	 */
	public void setOrderBn(String orderBn) {
		this.orderBn = orderBn;
	}
	/**
	 * @return the refundBn
	 */
	public String getRefundBn() {
		return refundBn;
	}
	/**
	 * @param refundBn the refundBn to set
	 */
	public void setRefundBn(String refundBn) {
		this.refundBn = refundBn;
	}
	/**
	 * @return the shopBn
	 */
	public String getShopBn() {
		return shopBn;
	}
	/**
	 * @param shopBn the shopBn to set
	 */
	public void setShopBn(String shopBn) {
		this.shopBn = shopBn;
	}
	/**
	 * @return the orderSource
	 */
	public String getOrderSource() {
		return orderSource;
	}
	/**
	 * @param orderSource the orderSource to set
	 */
	public void setOrderSource(String orderSource) {
		this.orderSource = orderSource;
	}
	/**
	 * @return the orderStatus
	 */
	public String getOrderStatus() {
		return orderStatus;
	}
	/**
	 * @return the orderTotalAmount
	 */
	public BigDecimal getOrderTotalAmount() {
		return orderTotalAmount;
	}
	/**
	 * @param orderTotalAmount the orderTotalAmount to set
	 */
	public void setOrderTotalAmount(BigDecimal orderTotalAmount) {
		this.orderTotalAmount = orderTotalAmount;
	}
	/**
	 * @return the orderCostAmount
	 */
	public BigDecimal getOrderCostAmount() {
		return orderCostAmount;
	}
	/**
	 * @param orderCostAmount the orderCostAmount to set
	 */
	public void setOrderCostAmount(BigDecimal orderCostAmount) {
		this.orderCostAmount = orderCostAmount;
	}
	/**
	 * @return the orderPmtOrder
	 */
	public BigDecimal getOrderPmtOrder() {
		return orderPmtOrder;
	}
	/**
	 * @param orderPmtOrder the orderPmtOrder to set
	 */
	public void setOrderPmtOrder(BigDecimal orderPmtOrder) {
		this.orderPmtOrder = orderPmtOrder;
	}
	/**
	 * @return the orderPmtPlateform
	 */
	public BigDecimal getOrderPmtPlateform() {
		return orderPmtPlateform;
	}
	/**
	 * @param orderPmtPlateform the orderPmtPlateform to set
	 */
	public void setOrderPmtPlateform(BigDecimal orderPmtPlateform) {
		this.orderPmtPlateform = orderPmtPlateform;
	}
	/**
	 * @return the orderPayed
	 */
	public BigDecimal getOrderPayed() {
		return orderPayed;
	}
	/**
	 * @param orderPayed the orderPayed to set
	 */
	public void setOrderPayed(BigDecimal orderPayed) {
		this.orderPayed = orderPayed;
	}
	/**
	 * @return the returnAmount
	 */
	public BigDecimal getReturnAmount() {
		return returnAmount;
	}
	/**
	 * @param returnAmount the returnAmount to set
	 */
	public void setReturnAmount(BigDecimal returnAmount) {
		this.returnAmount = returnAmount;
	}
	/**
	 * @param orderStatus the orderStatus to set
	 */
	public void setOrderStatus(String orderStatus) {
		this.orderStatus = orderStatus;
	}
	/**
	 * @return the returnReason
	 */
	public String getReturnReason() {
		return returnReason;
	}
	/**
	 * @param returnReason the returnReason to set
	 */
	public void setReturnReason(String returnReason) {
		this.returnReason = returnReason;
	}
	/**
	 * @return the returnExplain
	 */
	public String getReturnExplain() {
		return returnExplain;
	}
	/**
	 * @param returnExplain the returnExplain to set
	 */
	public void setReturnExplain(String returnExplain) {
		this.returnExplain = returnExplain;
	}
	/**
	 * @return the customMark
	 */
	public String getCustomMark() {
		return customMark;
	}
	/**
	 * @param customMark the customMark to set
	 */
	public void setCustomMark(String customMark) {
		this.customMark = customMark;
	}
	/**
	 * @return the returnProductInfos
	 */
	public List<ReturnProductInfoVo> getReturnProductInfos() {
		return returnProductInfos;
	}
	/**
	 * @param returnProductInfos the returnProductInfos to set
	 */
	public void setReturnProductInfos(List<ReturnProductInfoVo> returnProductInfos) {
		this.returnProductInfos = returnProductInfos;
	}
	/**
	 * @return the applyStatus
	 */
	public String getApplyStatus() {
		return applyStatus;
	}
	/**
	 * @param applyStatus the applyStatus to set
	 */
	public void setApplyStatus(String applyStatus) {
		this.applyStatus = applyStatus;
	}
	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}
	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return the zip
	 */
	public String getZip() {
		return zip;
	}
	/**
	 * @param zip the zip to set
	 */
	public void setZip(String zip) {
		this.zip = zip;
	}
	/**
	 * @return the areaState
	 */
	public String getAreaState() {
		return areaState;
	}
	/**
	 * @param areaState the areaState to set
	 */
	public void setAreaState(String areaState) {
		this.areaState = areaState;
	}
	/**
	 * @return the areaCity
	 */
	public String getAreaCity() {
		return areaCity;
	}
	/**
	 * @param areaCity the areaCity to set
	 */
	public void setAreaCity(String areaCity) {
		this.areaCity = areaCity;
	}
	/**
	 * @return the areaDistrict
	 */
	public String getAreaDistrict() {
		return areaDistrict;
	}
	/**
	 * @param areaDistrict the areaDistrict to set
	 */
	public void setAreaDistrict(String areaDistrict) {
		this.areaDistrict = areaDistrict;
	}
	/**
	 * @return the addr
	 */
	public String getAddr() {
		return addr;
	}
	/**
	 * @param addr the addr to set
	 */
	public void setAddr(String addr) {
		this.addr = addr;
	}
	/**
	 * @return the mobile
	 */
	public String getMobile() {
		return mobile;
	}
	/**
	 * @param mobile the mobile to set
	 */
	public void setMobile(String mobile) {
		this.mobile = mobile;
	}
	/**
	 * @return the telephone
	 */
	public String getTelephone() {
		return telephone;
	}
	/**
	 * @param telephone the telephone to set
	 */
	public void setTelephone(String telephone) {
		this.telephone = telephone;
	}
	/**
	 * @return the storeNo
	 */
	public String getStoreNo() {
		return storeNo;
	}
	/**
	 * @param storeNo the storeNo to set
	 */
	public void setStoreNo(String storeNo) {
		this.storeNo = storeNo;
	}
	/**
	 * @return the storeAddress
	 */
	public String getStoreAddress() {
		return storeAddress;
	}
	/**
	 * @param storeAddress the storeAddress to set
	 */
	public void setStoreAddress(String storeAddress) {
		this.storeAddress = storeAddress;
	}
	/**
	 * @return the platformSource
	 */
	public String getPlatformSource() {
		return platformSource;
	}
	/**
	 * @param platformSource the platformSource to set
	 */
	public void setPlatformSource(String platformSource) {
		this.platformSource = platformSource;
	}
	/**
	 * @return the operatorName
	 */
	public String getOperatorName() {
		return operatorName;
	}
	/**
	 * @param operatorName the operatorName to set
	 */
	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}
	/**
	 * @return the createtime
	 */
	public Date getCreatetime() {
		return createtime;
	}
	/**
	 * @param createtime the createtime to set
	 */
	public void setCreatetime(Date createtime) {
		this.createtime = createtime;
	}
	/**
	 * @return the applyTime
	 */
	public Date getApplyTime() {
		return applyTime;
	}
	/**
	 * @param applyTime the applyTime to set
	 */
	public void setApplyTime(Date applyTime) {
		this.applyTime = applyTime;
	}
	/**
	 * @return the logisticBn
	 */
	public String getLogisticBn() {
		return logisticBn;
	}
	/**
	 * @param logisticBn the logisticBn to set
	 */
	public void setLogisticBn(String logisticBn) {
		this.logisticBn = logisticBn;
	}
	/**
	 * @return the logisticCompany
	 */
	public String getLogisticCompany() {
		return logisticCompany;
	}
	/**
	 * @param logisticCompany the logisticCompany to set
	 */
	public void setLogisticCompany(String logisticCompany) {
		this.logisticCompany = logisticCompany;
	}
	/**
	 * @return the costShippig
	 */
	public BigDecimal getCostShippig() {
		return costShippig;
	}
	/**
	 * @param costShippig the costShippig to set
	 */
	public void setCostShippig(BigDecimal costShippig) {
		this.costShippig = costShippig;
	}
	/**
	 * @return the isProtect
	 */
	public boolean isProtect() {
		return isProtect;
	}
	/**
	 * @param isProtect the isProtect to set
	 */
	public void setProtect(boolean isProtect) {
		this.isProtect = isProtect;
	}
	/**
	 * @return the costProtect
	 */
	public BigDecimal getCostProtect() {
		return costProtect;
	}
	/**
	 * @param costProtect the costProtect to set
	 */
	public void setCostProtect(BigDecimal costProtect) {
		this.costProtect = costProtect;
	}
	/**
	 * @return the returnGoodsType
	 */
	public Integer getReturnGoodsType() {
		return returnGoodsType;
	}
	/**
	 * @param returnGoodsType the returnGoodsType to set
	 */
	public void setReturnGoodsType(Integer returnGoodsType) {
		this.returnGoodsType = returnGoodsType;
	}
	/**
	 * @return the returnGoodsProve
	 */
	public String getReturnGoodsProve() {
		return returnGoodsProve;
	}
	/**
	 * @param returnGoodsProve the returnGoodsProve to set
	 */
	public void setReturnGoodsProve(String returnGoodsProve) {
		this.returnGoodsProve = returnGoodsProve;
	}
	/**
	 * @return the payType
	 */
	public String getPayType() {
		return payType;
	}
	/**
	 * @param payType the payType to set
	 */
	public void setPayType(String payType) {
		this.payType = payType;
	}
	/**
	 * @return the accountBank
	 */
	public String getAccountBank() {
		return accountBank;
	}
	/**
	 * @param accountBank the accountBank to set
	 */
	public void setAccountBank(String accountBank) {
		this.accountBank = accountBank;
	}
	/**
	 * @return the accountNo
	 */
	public String getAccountNo() {
		return accountNo;
	}
	/**
	 * @param accountNo the accountNo to set
	 */
	public void setAccountNo(String accountNo) {
		this.accountNo = accountNo;
	}
	/**
	 * @return the refundState
	 */
	public String getRefundState() {
		return refundState;
	}
	/**
	 * @param refundState the refundState to set
	 */
	public void setRefundState(String refundState) {
		this.refundState = refundState;
	}
	/**
	 * @return the refundCity
	 */
	public String getRefundCity() {
		return refundCity;
	}
	/**
	 * @param refundCity the refundCity to set
	 */
	public void setRefundCity(String refundCity) {
		this.refundCity = refundCity;
	}
	/**
	 * @return the isAutoCreateRefund
	 */
	public Boolean getIsAutoCreateRefund() {
		return isAutoCreateRefund;
	}
	/**
	 * @param isAutoCreateRefund the isAutoCreateRefund to set
	 */
	public void setIsAutoCreateRefund(Boolean isAutoCreateRefund) {
		this.isAutoCreateRefund = isAutoCreateRefund;
	}
	
}

==> omsinterface-1.0.4-sources.jar: com/biz/oms/parseVo/returnGoods/ReturnGoodsVo.java <==
/**
 * @Description: 
 * @ClassName: com.biz.omsadmin.dto.ReturnGoodsDTO
 * @author: dick.dai(Administrator)
 * @date: 2016年5月12日 下午9:38:17 
 */
package com.biz.oms.parseVo.returnGoods;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 申请退货信息
 * @Description: 
 * @ClassName: com.biz.omsadmin.dto.ReturnGoodsDTO
 * @author: dick.dai(Administrator)
 * @date: 2016年5月12日 下午9:38:17 
 *
 */
public class ReturnGoodsVo implements Serializable{

	/**
	 * @Fields serialVersionUID : TODO
	 */
	private static final long serialVersionUID = 1L;
	
	private Integer id;
	/**退货单号*/
	private String returnGoodsBn;
	/**订单编号*/
	private String orderBn;
	/** 退款单号 */
	private String refundBn;
	/** 订单来源*/
	private String orderSource;
	/** 店铺来源*/
	private String shopBn;
	/** 订单状态*/
	private String orderStatus;
	/** 订单总金额*/
	private BigDecimal orderTotalAmount;
	/** 订单商品总金额*/
	private BigDecimal orderCostAmount;
	/** 订单优惠金额*/
	private BigDecimal orderPmtOrder;
	/** 原订单平台优惠*/
	private BigDecimal orderPmtPlateform;
	/** 订单已支付金额*/
	private BigDecimal orderPayed;
	/** 退款总金额*/
	private BigDecimal returnAmount;
	/**退货理由*/
	private String returnReason;
	/** 退货说明*/
	private String returnExplain;
	/** 客户备注*/
	private String customMark;
	/**退货商品信息*/
	private List<ReturnProductInfoVo> returnProductInfos=new ArrayList<ReturnProductInfoVo>();
	/**申请状态:默认为0：申请中*/
	private String applyStatus;
	/**退货人姓名*/
	private String name;
	/**邮编*/
	private String zip;
	/**省*/
	private String areaState;
	/**市/县*/
	private String areaCity;
	/**区*/
	private String areaDistrict;
	/**地址*/
	private String addr;
	/**手机号*/
	private String mobile;
	/**固定电话 */
	private String telephone;
	/** 退回的门店编号*/
	private String storeNo;
	/** 门店地址*/
	private String storeAddress;
	/** 平台来源*/
	private String platformSource;
	/** 操作人*/
	private String operatorName;
	/** 退货单创建时间*/
	private Date createtime;
	/** 退货单申请时间*/
	private Date applyTime;
	/** 物流编号*/
	private String logisticBn;
	/** 物流公司*/
	private String logisticCompany;
	/** 运费*/
	private BigDecimal costShippig;
	/** 是否保价*/
	private boolean isProtect;
	/** 保价费用*/
	private BigDecimal costProtect;
	/** 退货单类型 0:订单退货单  1:换货退货单  2:直返单*/
	private Integer returnGoodsType;
	/** 退货凭证*/
	private String returnGoodsProve;
	/** 退款支付方式*/
	private String payType;
	/** 退款银行*/
	private String accountBank;
	/** 退款银行卡号*/
	private String accountNo;
	/** 退款银行开户行省*/
	private String refundState;
	/** 退款银行开户行市*/	
	private String refundCity;
	/** 是否自动生成退款单*/
	private Boolean isAutoCreateRefund;
	/**销售员编号*/
	private String sellerCode;
	/**销售员姓名*/
	private String sellerName;
	/**
	 * @return the id
	 */
	public Integer getId() {
		return id;
	}
	/**
	 * @param id the id to set
	 */
	public void setId(Integer id) {
		this.id = id;
	}
	/**
	 * @return the returnGoodsBn
	 */
	public String getReturnGoodsBn() {
		return returnGoodsBn;
	}
	/**
	 * @param returnGoodsBn the returnGoodsBn to set
	 */
	public void setReturnGoodsBn(String returnGoodsBn) {
		this.returnGoodsBn = returnGoodsBn;
	}
	/**
	 * @return the orderBn
	 */
	public String getOrderBn() {
		return orderBn;
	}
	/**
	 * @param orderBn the orderBn to set
	 */
	public void setOrderBn(String orderBn) {
		this.orderBn = orderBn;
	}
	/**
	 * @return the refundBn
	 */
	public String getRefundBn() {
		return refundBn;
	}
	/**
	 * @param refundBn the refundBn to set
	 */
	public void setRefundBn(String refundBn) {
		this.refundBn = refundBn;
	}
	/**
	 * @return the shopBn
	 */
	public String getShopBn() {
		return shopBn;
	}
	/**
	 * @param shopBn the shopBn to set
	 */
	public void setShopBn(String shopBn) {
		this.shopBn = shopBn;
	}
	/**
	 * @return the orderSource
	 */
	public String getOrderSource() {
		return orderSource;
	}
	/**
	 * @param orderSource the orderSource to set
	 */
	public void setOrderSource(String orderSource) {
		this.orderSource = orderSource;
	}
	/**
	 * @return the orderStatus
	 */
	public String getOrderStatus() {
		return orderStatus;
	}
	/**
	 * @return the orderTotalAmount
	 */
	public BigDecimal getOrderTotalAmount() {
		return orderTotalAmount;
	}
	/**
	 * @param orderTotalAmount the orderTotalAmount to set
	 */
	public void setOrderTotalAmount(BigDecimal orderTotalAmount) {
		this.orderTotalAmount = orderTotalAmount;
	}
	/**
	 * @return the orderCostAmount
	 */
	public BigDecimal getOrderCostAmount() {
		return orderCostAmount;
	}
	/**
	 * @param orderCostAmount the orderCostAmount to set
	 */
	public void setOrderCostAmount(BigDecimal orderCostAmount) {
		this.orderCostAmount = orderCostAmount;
	}
	/**
	 * @return the orderPmtOrder
	 */
	public BigDecimal getOrderPmtOrder() {
		return orderPmtOrder;
	}
	/**
	 * @param orderPmtOrder the orderPmtOrder to set
	 */
	public void setOrderPmtOrder(BigDecimal orderPmtOrder) {
		this.orderPmtOrder = orderPmtOrder;
	}
	/**
	 * @return the orderPmtPlateform
	 */
	public BigDecimal getOrderPmtPlateform() {
		return orderPmtPlateform;
	}
	/**
	 * @param orderPmtPlateform the orderPmtPlateform to set
	 */
	public void setOrderPmtPlateform(BigDecimal orderPmtPlateform) {
		this.orderPmtPlateform = orderPmtPlateform;
	}
	/**
	 * @return the orderPayed
	 */
	public BigDecimal getOrderPayed() {
		return orderPayed;
	}
	/**
	 * @param orderPayed the orderPayed to set
	 */
	public void setOrderPayed(BigDecimal orderPayed) {
		this.orderPayed = orderPayed;
	}
	/**
	 * @return the returnAmount
	 */
	public BigDecimal getReturnAmount() {
		return returnAmount;
	}
	/**
	 * @param returnAmount the returnAmount to set
	 */
	public void setReturnAmount(BigDecimal returnAmount) {
		this.returnAmount = returnAmount;
	}
	/**
	 * @param orderStatus the orderStatus to set
	 */
	public void setOrderStatus(String orderStatus) {
		this.orderStatus = orderStatus;
	}
	/**
	 * @return the returnReason
	 */
	public String getReturnReason() {
		return returnReason;
	}
	/**
	 * @param returnReason the returnReason to set
	 */
	public void setReturnReason(String returnReason) {
		this.returnReason = returnReason;
	}
	/**
	 * @return the returnExplain
	 */
	public String getReturnExplain() {
		return returnExplain;
	}
	/**
	 * @param returnExplain the returnExplain to set
	 */
	public void setReturnExplain(String returnExplain) {
		this.returnExplain = returnExplain;
	}
	/**
	 * @return the customMark
	 */
	public String getCustomMark() {
		return customMark;
	}
	/**
	 * @param customMark the customMark to set
	 */
	public void setCustomMark(String customMark) {
		this.customMark = customMark;
	}
	/**
	 * @return the returnProductInfos
	 */
	public List<ReturnProductInfoVo> getReturnProductInfos() {
		return returnProductInfos;
	}
	/**
	 * @param returnProductInfos the returnProductInfos to set
	 */
	public void setReturnProductInfos(List<ReturnProductInfoVo> returnProductInfos) {
		this.returnProductInfos = returnProductInfos;
	}
	/**
	 * @return the applyStatus
	 */
	public String getApplyStatus() {
		return applyStatus;
	}
	/**
	 * @param applyStatus the applyStatus to set
	 */
	public void setApplyStatus(String applyStatus) {
		this.applyStatus = applyStatus;
	}
	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}
	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return the zip
	 */
	public String getZip() {
		return zip;
	}
	/**
	 * @param zip the zip to set
	 */
	public void setZip(String zip) {
		this.zip = zip;
	}
	/**
	 * @return the areaState
	 */
	public String getAreaState() {
		return areaState;
	}
	/**
	 * @param areaState the areaState to set
	 */
	public void setAreaState(String areaState) {
		this.areaState = areaState;
	}
	/**
	 * @return the areaCity
	 */
	public String getAreaCity() {
		return areaCity;
	}
	/**
	 * @param areaCity the areaCity to set
	 */
	public void setAreaCity(String areaCity) {
		this.areaCity = areaCity;
	}
	/**
	 * @return the areaDistrict
	 */
	public String getAreaDistrict() {
		return areaDistrict;
	}
	/**
	 * @param areaDistrict the areaDistrict to set
	 */
	public void setAreaDistrict(String areaDistrict) {
		this.areaDistrict = areaDistrict;
	}
	/**
	 * @return the addr
	 */
	public String getAddr() {
		return addr;
	}
	/**
	 * @param addr the addr to set
	 */
	public void setAddr(String addr) {
		this.addr = addr;
	}
	/**
	 * @return the mobile
	 */
	public String getMobile() {
		return mobile;
	}
	/**
	 * @param mobile the mobile to set
	 */
	public void setMobile(String mobile) {
		this.mobile = mobile;
	}
	/**
	 * @return the telephone
	 */
	public String getTelephone() {
		return telephone;
	}
	/**
	 * @param telephone the telephone to set
	 */
	public void setTelephone(String telephone) {
		this.telephone = telephone;
	}
	/**
	 * @return the storeNo
	 */
	public String getStoreNo() {
		return storeNo;
	}
	/**
	 * @param storeNo the storeNo to set
	 */
	public void setStoreNo(String storeNo) {
		this.storeNo = storeNo;
	}
	/**
	 * @return the storeAddress
	 */
	public String getStoreAddress() {
		return storeAddress;
	}
	/**
	 * @param storeAddress the storeAddress to set
	 */
	public void setStoreAddress(String storeAddress) {
		this.storeAddress = storeAddress;
	}
	/**
	 * @return the platformSource
	 */
	public String getPlatformSource() {
		return platformSource;
	}
	/**
	 * @param platformSource the platformSource to set
	 */
	public void setPlatformSource(String platformSource) {
		this.platformSource = platformSource;
	}
	/**
	 * @return the operatorName
	 */
	public String getOperatorName() {
		return operatorName;
	}
	/**
	 * @param operatorName the operatorName to set
	 */
	public void setOperatorName(String operatorName) {
		this.operatorName = operatorName;
	}
	/**
	 * @return the createtime
	 */
	public Date getCreatetime() {
		return createtime;
	}
	/**
	 * @param createtime the createtime to set
	 */
	public void setCreatetime(Date createtime) {
		this.createtime = createtime;
	}
	/**
	 * @return the applyTime
	 */
	public Date getApplyTime() {
		return applyTime;
	}
	/**
	 * @param applyTime the applyTime to set
	 */
	public void setApplyTime(Date applyTime) {
		this.applyTime = applyTime;
	}
	/**
	 * @return the logisticBn
	 */
	public String getLogisticBn() {
		return logisticBn;
	}
	/**
	 * @param logisticBn the logisticBn to set
	 */
	public void setLogisticBn(String logisticBn) {
		this.logisticBn = logisticBn;
	}
	/**
	 * @return the logisticCompany
	 */
	public String getLogisticCompany() {
		return logisticCompany;
	}
	/**
	 * @param logisticCompany the logisticCompany to set
	 */
	public void setLogisticCompany(String logisticCompany) {
		this.logisticCompany = logisticCompany;
	}
	/**
	 * @return the costShippig
	 */
	public BigDecimal getCostShippig() {
		return costShippig;
	}
	/**
	 * @param costShippig the costShippig to set
	 */
	public void setCostShippig(BigDecimal costShippig) {
		this.costShippig = costShippig;
	}
	/**
	 * @return the isProtect
	 */
	public boolean isProtect() {
		return isProtect;
	}
	/**
	 * @param isProtect the isProtect to set
	 */
	public void setProtect(boolean isProtect) {
		this.isProtect = isProtect;
	}
	/**
	 * @return the costProtect
	 */
	public BigDecimal getCostProtect() {
		return costProtect;
	}
	/**
	 * @param costProtect the costProtect to set
	 */
	public void setCostProtect(BigDecimal costProtect) {
		this.costProtect = costProtect;
	}
	/**
	 * @return the returnGoodsType
	 */
	public Integer getReturnGoodsType() {
		return returnGoodsType;
	}
	/**
	 * @param returnGoodsType the returnGoodsType to set
	 */
	public void setReturnGoodsType(Integer returnGoodsType) {
		this.returnGoodsType = returnGoodsType;
	}
	/**
	 * @return the returnGoodsProve
	 */
	public String getReturnGoodsProve() {
		return returnGoodsProve;
	}
	/**
	 * @param returnGoodsProve the returnGoodsProve to set
	 */
	public void setReturnGoodsProve(String returnGoodsProve) {
		this.returnGoodsProve = returnGoodsProve;
	}
	/**
	 * @return the payType
	 */
	public String getPayType() {
		return payType;
	}
	/**
	 * @param payType the payType to set
	 */
	public void setPayType(String payType) {
		this.payType = payType;
	}
	/**
	 * @return the accountBank
	 */
	public String getAccountBank() {
		return accountBank;
	}
	/**
	 * @param accountBank the accountBank to set
	 */
	public void setAccountBank(String accountBank) {
		this.accountBank = accountBank;
	}
	/**
	 * @return the accountNo
	 */
	public String getAccountNo() {
		return accountNo;
	}
	/**
	 * @param accountNo the accountNo to set
	 */
	public void setAccountNo(String accountNo) {
		this.accountNo = accountNo;
	}
	/**
	 * @return the refundState
	 */
	public String getRefundState() {
		return refundState;
	}
	/**
	 * @param refundState the refundState to set
	 */
	public void setRefundState(String refundState) {
		this.refundState = refundState;
	}
	/**
	 * @return the refundCity
	 */
	public String getRefundCity() {
		return refundCity;
	}
	/**
	 * @param refundCity the refundCity to set
	 */
	public void setRefundCity(String refundCity) {
		this.refundCity = refundCity;
	}
	/**
	 * @return the isAutoCreateRefund
	 */
	public Boolean getIsAutoCreateRefund() {
		return isAutoCreateRefund;
	}
	/**
	 * @param isAutoCreateRefund the isAutoCreateRefund to set
	 */
	public void setIsAutoCreateRefund(Boolean isAutoCreateRefund) {
		this.isAutoCreateRefund = isAutoCreateRefund;
	}
	public String getSellerCode() {
		return sellerCode;
	}
	public void setSellerCode(String sellerCode) {
		this.sellerCode = sellerCode;
	}
	public String getSellerName() {
		return sellerName;
	}
	public void setSellerName(String sellerName) {
		this.sellerName = sellerName;
	}
	
}
